.. _api-resultset:

=========
ResultSet
=========

.. _api-resultset-class:

.. autoclass:: protean.port.dao.ResultSet

.. _api-resultset-has_prev:

``has_prev``
^^^^^^^^^^^^

.. autoattribute:: protean.port.dao.ResultSet.has_prev

.. _api-resultset-has_next:

``has_next``
^^^^^^^^^^^^

.. autoattribute:: protean.port.dao.ResultSet.has_next

.. _api-resultset-first:

``first``
^^^^^^^^^

.. autoattribute:: protean.port.dao.ResultSet.first

.. _api-resultset-len:

``len``
^^^^^^^

.. automethod:: protean.port.dao.ResultSet.__len__

.. _api-resultset-bool:

``bool``
^^^^^^^^

.. automethod:: protean.port.dao.ResultSet.__bool__

.. _api-resultset-iter:

``iter``
^^^^^^^^

.. automethod:: protean.port.dao.ResultSet.__iter__
